perl_mongodb: A prerequisite for polymake's PolyDB feature
==========================================================

Description
-----------

This script package represents the Perl package MongoDB, which is needed for
the PolyDB feature of polymake.

License
-------

Various free software licenses
